@@ -465,8 +465,10 @@ class SyncGUI(object):
       templates.append(("SyncEvolution", "Generic SyncML", True))
     else:
       templates.append(("default", "Generic SyncML", True))
-
-    if std_backends.has_key("CardDAV") or std_backends.has_key("CalDAV"):
+    if "WebDAV" in std_templates:
+      std_templates.remove("WebDAV")
+      templates.append(("WebDAV", "Generic DAV", True))
+    elif std_backends.has_key("CardDAV") or std_backends.has_key("CalDAV"):
       templates.append((dav_template, "Generic DAV", True))
 
     # FIXME: perhaps also check for new ActiveSync template
